@@ -78,12 +78,12 @@ if (!is.gamlss(obj))  stop(paste("This is not an gamlss object", "\n", ""))
         if (("nu"%in%obj$parameters)) nu <- rep(fitted(obj,"nu"),K) 
         if (("tau"%in%obj$parameters)) tau <- rep(fitted(obj,"tau"),K)  
  switch(nopar,  
-    {lik <- if (fname%in%gamlss.bi.list) eval(call(dfun, y=yy, bd=bd,  mu=mu, log=TRUE))
-            else   eval(call(dfun, y=yy, mu=mu, log=TRUE))},
-    {lik <- if (fname%in%gamlss.bi.list) eval(call(dfun, y=yy, bd=bd,  mu=mu, sigma=sigma, log=TRUE ))
-            else   eval(call(dfun, y=yy, mu=mu, sigma=sigma, log=TRUE)) },
-    {lik <- eval(call(dfun,y=yy, mu=mu, sigma=sigma, nu=nu ,log=TRUE))},
-    {lik <- eval(call(dfun,y=yy, mu=mu, sigma=sigma, nu=nu, tau=tau,log=TRUE))})
+    {lik <- if (fname%in%gamlss.bi.list) eval(call(dfun, x=yy, bd=bd,  mu=mu, log=TRUE))
+            else   eval(call(dfun, x=yy, mu=mu, log=TRUE))},
+    {lik <- if (fname%in%gamlss.bi.list) eval(call(dfun, x=yy, bd=bd,  mu=mu, sigma=sigma, log=TRUE ))
+            else   eval(call(dfun, x=yy, mu=mu, sigma=sigma, log=TRUE)) },
+    {lik <- eval(call(dfun,x=yy, mu=mu, sigma=sigma, nu=nu ,log=TRUE))},
+    {lik <- eval(call(dfun,x=yy, mu=mu, sigma=sigma, nu=nu, tau=tau,log=TRUE))})
 lik
 }
 #----------------------------------------------------------------------------------------
@@ -97,12 +97,12 @@ if (!is.gamlss(obj))  stop(paste("This is not an gamlss object", "\n", ""))
    nopar <- length(DistPar) 
     dfun <- paste("d",fname,sep="")
  switch(nopar,  
-    { lik <- if (fname%in%gamlss.bi.list) eval(call(dfun,y=obj$y, bd=obj$bd,  mu=fitted(obj,"mu"), log=TRUE))
-             else   eval(call(dfun, y=obj$y, mu=fitted(obj, "mu"), log=TRUE))},
-    {lik <- if (fname%in%gamlss.bi.list)  eval(call(dfun,y=obj$y, bd=obj$bd,  mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), log=TRUE ))
-             else   eval(call(dfun, y=obj$y, mu=fitted(obj, "mu"), sigma=fitted(obj,"sigma"), log=TRUE)) },
-    {lik <- eval(call(dfun,y=obj$y, mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), nu=fitted(obj,"nu"),log=TRUE))},
-    {lik <- eval(call(dfun,y=obj$y, mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), nu=fitted(obj,"nu"), tau=fitted(obj,"tau"),log=TRUE))})
+    { lik <- if (fname%in%gamlss.bi.list) eval(call(dfun,x=obj$y, bd=obj$bd,  mu=fitted(obj,"mu"), log=TRUE))
+             else   eval(call(dfun, x=obj$y, mu=fitted(obj, "mu"), log=TRUE))},
+    {lik <- if (fname%in%gamlss.bi.list)  eval(call(dfun,x=obj$y, bd=obj$bd,  mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), log=TRUE ))
+             else   eval(call(dfun, x=obj$y, mu=fitted(obj, "mu"), sigma=fitted(obj,"sigma"), log=TRUE)) },
+    {lik <- eval(call(dfun,x=obj$y, mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), nu=fitted(obj,"nu"),log=TRUE))},
+    {lik <- eval(call(dfun,x=obj$y, mu=fitted(obj,"mu"), sigma=fitted(obj,"sigma"), nu=fitted(obj,"nu"), tau=fitted(obj,"tau"),log=TRUE))})
 lik
 }                          
 #----------------------------------------------------------------------------------------
